import uuid
from llama_index.core import SimpleDirectoryReader

from ..chunkers import BasicChunker
from ..embedding import OpenAIEmbedClient

class FileScraper:
    def __init__(
            self,
            files=[],
            chunker=BasicChunker(),
            embedding_client=OpenAIEmbedClient(),
            db_provder=None,
            group=None
    ):
        file_metadata = lambda x: {"filename": x}
        self.reader = SimpleDirectoryReader(input_files=files, file_metadata=file_metadata)
        self.chunker = chunker
        self.embedding_client = embedding_client
        self.db_provider = db_provder
        self.group = group

    def scrape(self):
        docs = self.reader.load_data()
        for doc in docs:
            chunks = self.chunker.get_chunks(doc.text)
            for chunk in chunks:
                if(bool(chunk.strip())):
                    self.db_provider.insert({
                        "id": str(uuid.uuid1()),
                        "title": doc.metadata.get("filename"),
                        "content": chunk,
                        "ref": doc.metadata.get("filename"),
                        "embedding": self.embedding_client.embed(str(chunk)),
                        "type": "file",
                        "group": self.group
                    })



import time

from scraper import WebScraper
from db import TiDBProvider
from chunkers import SemanticChunker
from embedding import OpenAIEmbedClient

import dotenv
dotenv.load_dotenv()

tidb = TiDBProvider()

tidb.connect()

embed_client = OpenAIEmbedClient(
    api_key="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"
)

scraper = WebScraper(
    urls=["https://www.pingcap.com/blog/"],
    follow_links=True,
    restrict_navigation_css=".tmpl-archive.tmpl-archive-blog",
    restrict_css=".tmpl-single-post__content",
    ignore_css=".tmpl-archive-sidebar",
    chunker=SemanticChunker(),
    db_provider=tidb,
    group="new-user-id",
    embedding_client=embed_client
)

scraper.crawl()

time.sleep(60)


from enum import Enum
from llama_index.embeddings.openai import OpenAIEmbedding

class OpenAIEmbedModel(str, Enum):
    TEXT_EMBED_ADA_002 = "text-embedding-ada-002"
    TEXT_EMBED_3_LARGE = "text-embedding-3-large"
    TEXT_EMBED_3_SMALL = "text-embedding-3-small"

class OpenAIEmbedClient(OpenAIEmbedding):
    
    def __init__(self, model=OpenAIEmbedModel.TEXT_EMBED_3_SMALL, api_key=None):
        super().__init__(
            model=model,
            api_key=api_key
        )

    def embed(self, text):
        return self.get_text_embedding(text)
